@@ -71,7 +71,7 @@ def _get_first_singular_vectors_power_method(
     try:
         y_score = next(col for col in Y.T if np.any(np.abs(col) > eps))
     except StopIteration as e:
-        raise StopIteration("Y residual is constant") from e
+        raise StopIteration("y residual is constant") from e
 
     x_weights_old = 100  # init to big value for first convergence check
 
@@ -161,6 +161,28 @@ def _svd_flip_1d(u, v):
     v *= sign
 
 
+# TODO(1.7): Remove
+def _deprecate_Y_when_optional(y, Y):
+    if Y is not None:
+        warnings.warn(
+            "`Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.",
+            FutureWarning,
+        )
+        if y is not None:
+            raise ValueError(
+                "Cannot use both `y` and `Y`. Use only `y` as `Y` is deprecated."
+            )
+        return Y
+    return y
+
+
+# TODO(1.7): Remove
+def _deprecate_Y_when_required(y, Y):
+    if y is None and Y is None:
+        raise ValueError("y is required.")
+    return _deprecate_Y_when_optional(y, Y)
+
+
 class _PLS(
     ClassNamePrefixFeaturesOutMixin,
     TransformerMixin,
@@ -212,7 +234,7 @@ class _PLS(
         self.copy = copy
 
     @_fit_context(prefer_skip_nested_validation=True)
-    def fit(self, X, Y):
+    def fit(self, X, y=None, Y=None):
         """Fit model to data.
 
         Parameters
@@ -221,31 +243,49 @@ class _PLS(
             Training vectors, where `n_samples` is the number of samples and
             `n_features` is the number of predictors.
 
+        y : array-like of shape (n_samples,) or (n_samples, n_targets)
+            Target vectors, where `n_samples` is the number of samples and
+            `n_targets` is the number of response variables.
+
         Y : array-like of shape (n_samples,) or (n_samples, n_targets)
             Target vectors, where `n_samples` is the number of samples and
             `n_targets` is the number of response variables.
 
+            .. deprecated:: 1.5
+               `Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.
+
         Returns
         -------
         self : object
             Fitted model.
         """
-        check_consistent_length(X, Y)
+        y = _deprecate_Y_when_required(y, Y)
+
+        check_consistent_length(X, y)
         X = self._validate_data(
-            X, dtype=np.float64, copy=self.copy, ensure_min_samples=2
+            X,
+            dtype=np.float64,
+            force_writeable=True,
+            copy=self.copy,
+            ensure_min_samples=2,
         )
-        Y = check_array(
-            Y, input_name="Y", dtype=np.float64, copy=self.copy, ensure_2d=False
+        y = check_array(
+            y,
+            input_name="y",
+            dtype=np.float64,
+            force_writeable=True,
+            copy=self.copy,
+            ensure_2d=False,
         )
-        if Y.ndim == 1:
+        if y.ndim == 1:
             self._predict_1d = True
-            Y = Y.reshape(-1, 1)
+            y = y.reshape(-1, 1)
         else:
             self._predict_1d = False
 
         n = X.shape[0]
         p = X.shape[1]
-        q = Y.shape[1]
+        q = y.shape[1]
 
         n_components = self.n_components
         # With PLSRegression n_components is bounded by the rank of (X.T X) see
@@ -262,8 +302,8 @@ class _PLS(
         norm_y_weights = self._norm_y_weights
 
         # Scale (in place)
-        Xk, Yk, self._x_mean, self._y_mean, self._x_std, self._y_std = _center_scale_xy(
-            X, Y, self.scale
+        Xk, yk, self._x_mean, self._y_mean, self._x_std, self._y_std = _center_scale_xy(
+            X, y, self.scale
         )
 
         self.x_weights_ = np.zeros((p, n_components))  # U
@@ -277,14 +317,14 @@ class _PLS(
         # This whole thing corresponds to the algorithm in section 4.1 of the
         # review from Wegelin. See above for a notation mapping from code to
         # paper.
-        Y_eps = np.finfo(Yk.dtype).eps
+        y_eps = np.finfo(yk.dtype).eps
         for k in range(n_components):
             # Find first left and right singular vectors of the X.T.dot(Y)
             # cross-covariance matrix.
             if self.algorithm == "nipals":
                 # Replace columns that are all close to zero with zeros
-                Yk_mask = np.all(np.abs(Yk) < 10 * Y_eps, axis=0)
-                Yk[:, Yk_mask] = 0.0
+                yk_mask = np.all(np.abs(yk) < 10 * y_eps, axis=0)
+                yk[:, yk_mask] = 0.0
 
                 try:
                     (
@@ -293,22 +333,22 @@ class _PLS(
                         n_iter_,
                     ) = _get_first_singular_vectors_power_method(
                         Xk,
-                        Yk,
+                        yk,
                         mode=self.mode,
                         max_iter=self.max_iter,
                         tol=self.tol,
                         norm_y_weights=norm_y_weights,
                     )
                 except StopIteration as e:
-                    if str(e) != "Y residual is constant":
+                    if str(e) != "y residual is constant":
                         raise
-                    warnings.warn(f"Y residual is constant at iteration {k}")
+                    warnings.warn(f"y residual is constant at iteration {k}")
                     break
 
                 self.n_iter_.append(n_iter_)
 
             elif self.algorithm == "svd":
-                x_weights, y_weights = _get_first_singular_vectors_svd(Xk, Yk)
+                x_weights, y_weights = _get_first_singular_vectors_svd(Xk, yk)
 
             # inplace sign flip for consistency across solvers and archs
             _svd_flip_1d(x_weights, y_weights)
@@ -319,7 +359,7 @@ class _PLS(
                 y_ss = 1
             else:
                 y_ss = np.dot(y_weights, y_weights)
-            y_scores = np.dot(Yk, y_weights) / y_ss
+            y_scores = np.dot(yk, y_weights) / y_ss
 
             # Deflation: subtract rank-one approx to obtain Xk+1 and Yk+1
             x_loadings = np.dot(x_scores, Xk) / np.dot(x_scores, x_scores)
@@ -327,12 +367,12 @@ class _PLS(
 
             if self.deflation_mode == "canonical":
                 # regress Yk on y_score
-                y_loadings = np.dot(y_scores, Yk) / np.dot(y_scores, y_scores)
-                Yk -= np.outer(y_scores, y_loadings)
+                y_loadings = np.dot(y_scores, yk) / np.dot(y_scores, y_scores)
+                yk -= np.outer(y_scores, y_loadings)
             if self.deflation_mode == "regression":
                 # regress Yk on x_score
-                y_loadings = np.dot(x_scores, Yk) / np.dot(x_scores, x_scores)
-                Yk -= np.outer(x_scores, y_loadings)
+                y_loadings = np.dot(x_scores, yk) / np.dot(x_scores, x_scores)
+                yk -= np.outer(x_scores, y_loadings)
 
             self.x_weights_[:, k] = x_weights
             self.y_weights_[:, k] = y_weights
@@ -345,7 +385,7 @@ class _PLS(
         # Xi . Gamma.T is a sum of n_components rank-1 matrices. X_(R+1) is
         # whatever is left to fully reconstruct X, and can be 0 if X is of rank
         # n_components.
-        # Similarly, Y was approximated as Omega . Delta.T + Y_(R+1)
+        # Similarly, y was approximated as Omega . Delta.T + y_(R+1)
 
         # Compute transformation matrices (rotations_). See User Guide.
         self.x_rotations_ = np.dot(
@@ -357,12 +397,12 @@ class _PLS(
             pinv2(np.dot(self.y_loadings_.T, self.y_weights_), check_finite=False),
         )
         self.coef_ = np.dot(self.x_rotations_, self.y_loadings_.T)
-        self.coef_ = (self.coef_ * self._y_std).T
+        self.coef_ = (self.coef_ * self._y_std).T / self._x_std
         self.intercept_ = self._y_mean
         self._n_features_out = self.x_rotations_.shape[1]
         return self
 
-    def transform(self, X, Y=None, copy=True):
+    def transform(self, X, y=None, Y=None, copy=True):
         """Apply the dimension reduction.
 
         Parameters
@@ -370,9 +410,15 @@ class _PLS(
         X : array-like of shape (n_samples, n_features)
             Samples to transform.
 
+        y : array-like of shape (n_samples, n_targets), default=None
+            Target vectors.
+
         Y : array-like of shape (n_samples, n_targets), default=None
             Target vectors.
 
+            .. deprecated:: 1.5
+               `Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.
+
         copy : bool, default=True
             Whether to copy `X` and `Y`, or perform in-place normalization.
 
@@ -381,6 +427,8 @@ class _PLS(
         x_scores, y_scores : array-like or tuple of array-like
             Return `x_scores` if `Y` is not given, `(x_scores, y_scores)` otherwise.
         """
+        y = _deprecate_Y_when_optional(y, Y)
+
         check_is_fitted(self)
         X = self._validate_data(X, copy=copy, dtype=FLOAT_DTYPES, reset=False)
         # Normalize
@@ -388,20 +436,20 @@ class _PLS(
         X /= self._x_std
         # Apply rotation
         x_scores = np.dot(X, self.x_rotations_)
-        if Y is not None:
-            Y = check_array(
-                Y, input_name="Y", ensure_2d=False, copy=copy, dtype=FLOAT_DTYPES
+        if y is not None:
+            y = check_array(
+                y, input_name="y", ensure_2d=False, copy=copy, dtype=FLOAT_DTYPES
             )
-            if Y.ndim == 1:
-                Y = Y.reshape(-1, 1)
-            Y -= self._y_mean
-            Y /= self._y_std
-            y_scores = np.dot(Y, self.y_rotations_)
+            if y.ndim == 1:
+                y = y.reshape(-1, 1)
+            y -= self._y_mean
+            y /= self._y_std
+            y_scores = np.dot(y, self.y_rotations_)
             return x_scores, y_scores
 
         return x_scores
 
-    def inverse_transform(self, X, Y=None):
+    def inverse_transform(self, X, y=None, Y=None):
         """Transform data back to its original space.
 
         Parameters
@@ -410,22 +458,31 @@ class _PLS(
             New data, where `n_samples` is the number of samples
             and `n_components` is the number of pls components.
 
+        y : array-like of shape (n_samples,) or (n_samples, n_components)
+            New target, where `n_samples` is the number of samples
+            and `n_components` is the number of pls components.
+
         Y : array-like of shape (n_samples, n_components)
             New target, where `n_samples` is the number of samples
             and `n_components` is the number of pls components.
 
+            .. deprecated:: 1.5
+               `Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.
+
         Returns
         -------
         X_reconstructed : ndarray of shape (n_samples, n_features)
             Return the reconstructed `X` data.
 
-        Y_reconstructed : ndarray of shape (n_samples, n_targets)
-            Return the reconstructed `X` target. Only returned when `Y` is given.
+        y_reconstructed : ndarray of shape (n_samples, n_targets)
+            Return the reconstructed `X` target. Only returned when `y` is given.
 
         Notes
         -----
         This transformation will only be exact if `n_components=n_features`.
         """
+        y = _deprecate_Y_when_optional(y, Y)
+
         check_is_fitted(self)
         X = check_array(X, input_name="X", dtype=FLOAT_DTYPES)
         # From pls space to original space
@@ -434,14 +491,14 @@ class _PLS(
         X_reconstructed *= self._x_std
         X_reconstructed += self._x_mean
 
-        if Y is not None:
-            Y = check_array(Y, input_name="Y", dtype=FLOAT_DTYPES)
+        if y is not None:
+            y = check_array(y, input_name="y", dtype=FLOAT_DTYPES)
             # From pls space to original space
-            Y_reconstructed = np.matmul(Y, self.y_loadings_.T)
+            y_reconstructed = np.matmul(y, self.y_loadings_.T)
             # Denormalize
-            Y_reconstructed *= self._y_std
-            Y_reconstructed += self._y_mean
-            return X_reconstructed, Y_reconstructed
+            y_reconstructed *= self._y_std
+            y_reconstructed += self._y_mean
+            return X_reconstructed, y_reconstructed
 
         return X_reconstructed
 
@@ -469,9 +526,8 @@ class _PLS(
         """
         check_is_fitted(self)
         X = self._validate_data(X, copy=copy, dtype=FLOAT_DTYPES, reset=False)
-        # Normalize
+        # Only center X but do not scale it since the coefficients are already scaled
         X -= self._x_mean
-        X /= self._x_std
         Ypred = X @ self.coef_.T + self.intercept_
         return Ypred.ravel() if self._predict_1d else Ypred
 
@@ -505,6 +561,9 @@ class PLSRegression(_PLS):
     PLSRegression is also known as PLS2 or PLS1, depending on the number of
     targets.
 
+    For a comparison between other cross decomposition algorithms, see
+    :ref:`sphx_glr_auto_examples_cross_decomposition_plot_compare_cross_decomposition.py`.
+
     Read more in the :ref:`User Guide <cross_decomposition>`.
 
     .. versionadded:: 0.8
@@ -512,8 +571,7 @@ class PLSRegression(_PLS):
     Parameters
     ----------
     n_components : int, default=2
-        Number of components to keep. Should be in `[1, min(n_samples,
-        n_features, n_targets)]`.
+        Number of components to keep. Should be in `[1, n_features]`.
 
     scale : bool, default=True
         Whether to scale `X` and `Y`.
@@ -591,11 +649,14 @@ class PLSRegression(_PLS):
     --------
     >>> from sklearn.cross_decomposition import PLSRegression
     >>> X = [[0., 0., 1.], [1.,0.,0.], [2.,2.,2.], [2.,5.,4.]]
-    >>> Y = [[0.1, -0.2], [0.9, 1.1], [6.2, 5.9], [11.9, 12.3]]
+    >>> y = [[0.1, -0.2], [0.9, 1.1], [6.2, 5.9], [11.9, 12.3]]
     >>> pls2 = PLSRegression(n_components=2)
-    >>> pls2.fit(X, Y)
+    >>> pls2.fit(X, y)
     PLSRegression()
     >>> Y_pred = pls2.predict(X)
+
+    For a comparison between PLS Regression and :class:`~sklearn.decomposition.PCA`, see
+    :ref:`sphx_glr_auto_examples_cross_decomposition_plot_pcr_vs_pls.py`.
     """
 
     _parameter_constraints: dict = {**_PLS._parameter_constraints}
@@ -622,7 +683,7 @@ class PLSRegression(_PLS):
             copy=copy,
         )
 
-    def fit(self, X, Y):
+    def fit(self, X, y=None, Y=None):
         """Fit model to data.
 
         Parameters
@@ -631,16 +692,25 @@ class PLSRegression(_PLS):
             Training vectors, where `n_samples` is the number of samples and
             `n_features` is the number of predictors.
 
+        y : array-like of shape (n_samples,) or (n_samples, n_targets)
+            Target vectors, where `n_samples` is the number of samples and
+            `n_targets` is the number of response variables.
+
         Y : array-like of shape (n_samples,) or (n_samples, n_targets)
             Target vectors, where `n_samples` is the number of samples and
             `n_targets` is the number of response variables.
 
+            .. deprecated:: 1.5
+               `Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.
+
         Returns
         -------
         self : object
             Fitted model.
         """
-        super().fit(X, Y)
+        y = _deprecate_Y_when_required(y, Y)
+
+        super().fit(X, y)
         # expose the fitted attributes `x_scores_` and `y_scores_`
         self.x_scores_ = self._x_scores
         self.y_scores_ = self._y_scores
@@ -650,6 +720,9 @@ class PLSRegression(_PLS):
 class PLSCanonical(_PLS):
     """Partial Least Squares transformer and regressor.
 
+    For a comparison between other cross decomposition algorithms, see
+    :ref:`sphx_glr_auto_examples_cross_decomposition_plot_compare_cross_decomposition.py`.
+
     Read more in the :ref:`User Guide <cross_decomposition>`.
 
     .. versionadded:: 0.8
@@ -736,11 +809,11 @@ class PLSCanonical(_PLS):
     --------
     >>> from sklearn.cross_decomposition import PLSCanonical
     >>> X = [[0., 0., 1.], [1.,0.,0.], [2.,2.,2.], [2.,5.,4.]]
-    >>> Y = [[0.1, -0.2], [0.9, 1.1], [6.2, 5.9], [11.9, 12.3]]
+    >>> y = [[0.1, -0.2], [0.9, 1.1], [6.2, 5.9], [11.9, 12.3]]
     >>> plsca = PLSCanonical(n_components=2)
-    >>> plsca.fit(X, Y)
+    >>> plsca.fit(X, y)
     PLSCanonical()
-    >>> X_c, Y_c = plsca.transform(X, Y)
+    >>> X_c, y_c = plsca.transform(X, y)
     """
 
     _parameter_constraints: dict = {**_PLS._parameter_constraints}
@@ -780,6 +853,9 @@ class PLSCanonical(_PLS):
 class CCA(_PLS):
     """Canonical Correlation Analysis, also known as "Mode B" PLS.
 
+    For a comparison between other cross decomposition algorithms, see
+    :ref:`sphx_glr_auto_examples_cross_decomposition_plot_compare_cross_decomposition.py`.
+
     Read more in the :ref:`User Guide <cross_decomposition>`.
 
     Parameters
@@ -858,11 +934,11 @@ class CCA(_PLS):
     --------
     >>> from sklearn.cross_decomposition import CCA
     >>> X = [[0., 0., 1.], [1.,0.,0.], [2.,2.,2.], [3.,5.,4.]]
-    >>> Y = [[0.1, -0.2], [0.9, 1.1], [6.2, 5.9], [11.9, 12.3]]
+    >>> y = [[0.1, -0.2], [0.9, 1.1], [6.2, 5.9], [11.9, 12.3]]
     >>> cca = CCA(n_components=1)
-    >>> cca.fit(X, Y)
+    >>> cca.fit(X, y)
     CCA(n_components=1)
-    >>> X_c, Y_c = cca.transform(X, Y)
+    >>> X_c, Y_c = cca.transform(X, y)
     """
 
     _parameter_constraints: dict = {**_PLS._parameter_constraints}
@@ -942,13 +1018,13 @@ class PLSSVD(ClassNamePrefixFeaturesOutMixin, TransformerMixin, BaseEstimator):
     ...               [1., 0., 0.],
     ...               [2., 2., 2.],
     ...               [2., 5., 4.]])
-    >>> Y = np.array([[0.1, -0.2],
+    >>> y = np.array([[0.1, -0.2],
     ...               [0.9, 1.1],
     ...               [6.2, 5.9],
     ...               [11.9, 12.3]])
-    >>> pls = PLSSVD(n_components=2).fit(X, Y)
-    >>> X_c, Y_c = pls.transform(X, Y)
-    >>> X_c.shape, Y_c.shape
+    >>> pls = PLSSVD(n_components=2).fit(X, y)
+    >>> X_c, y_c = pls.transform(X, y)
+    >>> X_c.shape, y_c.shape
     ((4, 2), (4, 2))
     """
 
@@ -964,7 +1040,7 @@ class PLSSVD(ClassNamePrefixFeaturesOutMixin, TransformerMixin, BaseEstimator):
         self.copy = copy
 
     @_fit_context(prefer_skip_nested_validation=True)
-    def fit(self, X, Y):
+    def fit(self, X, y=None, Y=None):
         """Fit model to data.
 
         Parameters
@@ -972,41 +1048,57 @@ class PLSSVD(ClassNamePrefixFeaturesOutMixin, TransformerMixin, BaseEstimator):
         X : array-like of shape (n_samples, n_features)
             Training samples.
 
+        y : array-like of shape (n_samples,) or (n_samples, n_targets)
+            Targets.
+
         Y : array-like of shape (n_samples,) or (n_samples, n_targets)
             Targets.
 
+            .. deprecated:: 1.5
+               `Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.
+
         Returns
         -------
         self : object
             Fitted estimator.
         """
-        check_consistent_length(X, Y)
+        y = _deprecate_Y_when_required(y, Y)
+        check_consistent_length(X, y)
         X = self._validate_data(
-            X, dtype=np.float64, copy=self.copy, ensure_min_samples=2
+            X,
+            dtype=np.float64,
+            force_writeable=True,
+            copy=self.copy,
+            ensure_min_samples=2,
         )
-        Y = check_array(
-            Y, input_name="Y", dtype=np.float64, copy=self.copy, ensure_2d=False
+        y = check_array(
+            y,
+            input_name="y",
+            dtype=np.float64,
+            force_writeable=True,
+            copy=self.copy,
+            ensure_2d=False,
         )
-        if Y.ndim == 1:
-            Y = Y.reshape(-1, 1)
+        if y.ndim == 1:
+            y = y.reshape(-1, 1)
 
-        # we'll compute the SVD of the cross-covariance matrix = X.T.dot(Y)
+        # we'll compute the SVD of the cross-covariance matrix = X.T.dot(y)
         # This matrix rank is at most min(n_samples, n_features, n_targets) so
         # n_components cannot be bigger than that.
         n_components = self.n_components
-        rank_upper_bound = min(X.shape[0], X.shape[1], Y.shape[1])
+        rank_upper_bound = min(X.shape[0], X.shape[1], y.shape[1])
         if n_components > rank_upper_bound:
             raise ValueError(
                 f"`n_components` upper bound is {rank_upper_bound}. "
                 f"Got {n_components} instead. Reduce `n_components`."
             )
 
-        X, Y, self._x_mean, self._y_mean, self._x_std, self._y_std = _center_scale_xy(
-            X, Y, self.scale
+        X, y, self._x_mean, self._y_mean, self._x_std, self._y_std = _center_scale_xy(
+            X, y, self.scale
         )
 
         # Compute SVD of cross-covariance matrix
-        C = np.dot(X.T, Y)
+        C = np.dot(X.T, y)
         U, s, Vt = svd(C, full_matrices=False)
         U = U[:, :n_components]
         Vt = Vt[:n_components]
@@ -1018,7 +1110,7 @@ class PLSSVD(ClassNamePrefixFeaturesOutMixin, TransformerMixin, BaseEstimator):
         self._n_features_out = self.x_weights_.shape[1]
         return self
 
-    def transform(self, X, Y=None):
+    def transform(self, X, y=None, Y=None):
         """
         Apply the dimensionality reduction.
 
@@ -1027,26 +1119,34 @@ class PLSSVD(ClassNamePrefixFeaturesOutMixin, TransformerMixin, BaseEstimator):
         X : array-like of shape (n_samples, n_features)
             Samples to be transformed.
 
+        y : array-like of shape (n_samples,) or (n_samples, n_targets), \
+                default=None
+            Targets.
+
         Y : array-like of shape (n_samples,) or (n_samples, n_targets), \
                 default=None
             Targets.
 
+            .. deprecated:: 1.5
+               `Y` is deprecated in 1.5 and will be removed in 1.7. Use `y` instead.
+
         Returns
         -------
         x_scores : array-like or tuple of array-like
             The transformed data `X_transformed` if `Y is not None`,
             `(X_transformed, Y_transformed)` otherwise.
         """
+        y = _deprecate_Y_when_optional(y, Y)
         check_is_fitted(self)
         X = self._validate_data(X, dtype=np.float64, reset=False)
         Xr = (X - self._x_mean) / self._x_std
         x_scores = np.dot(Xr, self.x_weights_)
-        if Y is not None:
-            Y = check_array(Y, input_name="Y", ensure_2d=False, dtype=np.float64)
-            if Y.ndim == 1:
-                Y = Y.reshape(-1, 1)
-            Yr = (Y - self._y_mean) / self._y_std
-            y_scores = np.dot(Yr, self.y_weights_)
+        if y is not None:
+            y = check_array(y, input_name="y", ensure_2d=False, dtype=np.float64)
+            if y.ndim == 1:
+                y = y.reshape(-1, 1)
+            yr = (y - self._y_mean) / self._y_std
+            y_scores = np.dot(yr, self.y_weights_)
             return x_scores, y_scores
         return x_scores
 
