@@ -1,6 +1,7 @@
 """
 Sequential feature selection
 """
+
 from numbers import Integral, Real
 
 import numpy as np
@@ -10,11 +11,14 @@ from ..metrics import get_scorer_names
 from ..model_selection import check_cv, cross_val_score
 from ..utils._param_validation import HasMethods, Interval, RealNotInt, StrOptions
 from ..utils._tags import _safe_tags
+from ..utils.metadata_routing import _RoutingNotSupportedMixin
 from ..utils.validation import check_is_fitted
 from ._base import SelectorMixin
 
 
-class SequentialFeatureSelector(SelectorMixin, MetaEstimatorMixin, BaseEstimator):
+class SequentialFeatureSelector(
+    _RoutingNotSupportedMixin, SelectorMixin, MetaEstimatorMixin, BaseEstimator
+):
     """Transformer that performs Sequential Feature Selection.
 
     This Sequential Feature Selector adds (forward selection) or
